==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/km-KH/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'បញ្ជាក់ការលុបភាគច្រើន',
    'bulk_restore'      => 'បញ្ជាក់​ការ​ស្ដារ​ Assets ភាគច្រើន', 
  'bulk_delete_help'	=> 'ពិនិត្យមើលទ្រព្យសម្បត្តិសម្រាប់ការលុបភាគច្រើនខាងក្រោម។ នៅពេលដែលបានលុប ទ្រព្យសម្បត្តិទាំងនេះអាចត្រូវបានស្ដារឡើងវិញ ប៉ុន្តែពួកវានឹងលែងត្រូវបានភ្ជាប់ជាមួយនឹងអ្នកប្រើប្រាស់ណាមួយដែលពួកគេត្រូវបានគេចាត់ឱ្យទៅនាពេលបច្ចុប្បន្ននេះ។',
  'bulk_restore_help'	=> 'ពិនិត្យមើលទ្រព្យសម្បត្តិសម្រាប់ការស្ដារឡើងវិញភាគច្រើនខាងក្រោម។ នៅពេលដែលបានស្ដារឡើងវិញ ទ្រព្យសម្បត្តិទាំងនេះនឹងមិនត្រូវបានភ្ជាប់ជាមួយអ្នកប្រើប្រាស់ណាមួយដែលពួកគេត្រូវបានគេចាត់ឱ្យពីមុននោះទេ។',
  'bulk_delete_warn'	=> 'អ្នកហៀបនឹងលុប៖ asset រាប់ទ្រព្យសកម្ម។',
  'bulk_restore_warn'	=> 'អ្នកហៀបនឹងស្ដារ :asset_count ទ្រព្យសកម្ម។',
    'bulk_update'		=> 'ទ្រព្យសម្បត្តិអាប់ដេតភាគច្រើន',
    'bulk_update_help'	=> 'ទម្រង់បែបបទនេះអនុញ្ញាតឱ្យអ្នកធ្វើបច្ចុប្បន្នភាពទ្រព្យសម្បត្តិច្រើនក្នុងពេលតែមួយ។ បំពេញតែក្នុងវាលដែលអ្នកត្រូវការផ្លាស់ប្តូរ។ វាល​ណា​មួយ​ដែល​ទុក​នៅ​ទទេ​នឹង​នៅ​តែ​មិន​ផ្លាស់​ប្តូរ។ ',
    'bulk_update_warn'	=> 'អ្នក​រៀប​នឹង​កែ​សម្រួល​លក្ខណៈ​សម្បត្តិ​នៃ​ទ្រព្យ​សកម្ម​តែ​មួយ។|អ្នក​រៀប​នឹង​កែ​សម្រួល​លក្ខណៈ​សម្បត្តិ​របស់ :asset_count assets។',
    'bulk_update_with_custom_field' => 'ចំណាំទ្រព្យសកម្មគឺ :asset_model_count ប្រភេទផ្សេងគ្នានៃគំរូ។',
    'bulk_update_model_prefix' => 'នៅលើម៉ូដែល', 
    'bulk_update_custom_field_unique' => 'នេះ​គឺ​ជា​វាល​ពិសេស​មួយ ហើយ​មិន​អាច​ត្រូវ​បាន​កែ​សម្រួល​ច្រើន​ទេ។',
    'checkedout_to'		=> 'ប្រគល់ទៅអោយ',
    'checkout_date'		=> 'ថ្ងៃប្រគល់អោយ',
    'checkin_date'		=> 'កាលបរិច្ឆេទត្រឡប់មកវិញ',
    'checkout_to'		=> 'Checkout to',
    'cost'				=> 'ការចំណាយលើការទិញ',
    'create'			=> 'បង្កើតទ្រព្យសកម្ម',
    'date'				=> 'កាលបរិច្ឆេទទិញ',
    'depreciation'	    => 'ការរំលោះ',
    'depreciates_on'	=> 'ទម្លាក់តម្លៃលើ',
    'default_location'	=> 'ទីតាំងលំនាំដើម',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'កាលបរិច្ឆេទនៃ EOL',
    'eol_rate'			=> 'អត្រា EOL',
    'expected_checkin'  => 'កាលបរិច្ឆេទដែលរំពឹងទុកនឹង Checkin',
    'expires'			=> 'ផុតកំណត់',
    'fully_depreciated'	=> 'រំលោះទាំងស្រុង',
    'help_checkout'		=> 'ប្រសិនបើអ្នកចង់ផ្តល់ asset នេះភ្លាមៗ សូមជ្រើសរើស "Ready to Deploy" ពីបញ្ជីស្ថានភាពខាងលើ។ ',
    'mac_address'		=> 'MAC Address',
    'manufacturer'		=> 'ក្រុមហ៊ុនផលិត',
    'model'				=> 'គំរូ',
    'months'			=> 'ខែ',
    'name'				=> 'ឈ្មោះទ្រព្យសម្បត្តិ',
    'notes'				=> 'កំណត់ចំណាំ',
    'order'				=> 'លេខបញ្ជាទិញ',
    'qr'				=> 'QR Code',
    'requestable'		=> 'អ្នកប្រើប្រាស់អាចស្នើសុំ Asset នេះ',
    'select_statustype'	=> 'ជ្រើសរើសប្រភេទស្ថានភាព',
    'serial'			=> 'Serial',
    'status'			=> 'ស្ថានភាព',
    'tag'				=> 'ទ្រព្យសម្បត្តិ',
    'update'			=> 'ធ្វើបច្ចុប្បន្នភាព Asset',
    'warranty'			=> 'ការធានា',
        'warranty_expires'		=> 'ការធានាផុតកំណត់',
    'years'				=> 'ឆ្នាំ',
    'asset_location' => 'ធ្វើបច្ចុប្បន្នភាពទីតាំង Asset',
    'asset_location_update_default_current' => 'ធ្វើបច្ចុប្បន្នភាពទីតាំងលំនាំដើម និងទីតាំងជាក់ស្តែង',
    'asset_location_update_default' => 'ធ្វើបច្ចុប្បន្នភាពតែទីតាំងលំនាំដើមប៉ុណ្ណោះ។',
    'asset_location_update_actual' => 'ធ្វើបច្ចុប្បន្នភាពតែទីតាំងជាក់ស្តែងប៉ុណ្ណោះ។',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'កំពុងដំណើរការ... (វាអាចចំណាយពេលបន្តិចលើឯកសារធំ)',
    'optional_infos'  => 'ព័ត៌មានមិនសូវចាំបាច់',
    'order_details'   => 'ព័ត៌មានពាក់ព័ន្ធនឹងការបញ្ជាទិញ'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/km-KH/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'បញ្ជាក់ការលុបភាគច្រើន',
    'bulk_restore'      => 'បញ្ជាក់​ការ​ស្ដារ​ Assets ភាគច្រើន', 
  'bulk_delete_help'	=> 'ពិនិត្យមើលទ្រព្យសម្បត្តិសម្រាប់ការលុបភាគច្រើនខាងក្រោម។ នៅពេលដែលបានលុប ទ្រព្យសម្បត្តិទាំងនេះអាចត្រូវបានស្ដារឡើងវិញ ប៉ុន្តែពួកវានឹងលែងត្រូវបានភ្ជាប់ជាមួយនឹងអ្នកប្រើប្រាស់ណាមួយដែលពួកគេត្រូវបានគេចាត់ឱ្យទៅនាពេលបច្ចុប្បន្ននេះ។',
  'bulk_restore_help'	=> 'ពិនិត្យមើលទ្រព្យសម្បត្តិសម្រាប់ការស្ដារឡើងវិញភាគច្រើនខាងក្រោម។ នៅពេលដែលបានស្ដារឡើងវិញ ទ្រព្យសម្បត្តិទាំងនេះនឹងមិនត្រូវបានភ្ជាប់ជាមួយអ្នកប្រើប្រាស់ណាមួយដែលពួកគេត្រូវបានគេចាត់ឱ្យពីមុននោះទេ។',
  'bulk_delete_warn'	=> 'អ្នកហៀបនឹងលុប៖ asset រាប់ទ្រព្យសកម្ម។',
  'bulk_restore_warn'	=> 'អ្នកហៀបនឹងស្ដារ :asset_count ទ្រព្យសកម្ម។',
    'bulk_update'		=> 'ទ្រព្យសម្បត្តិអាប់ដេតភាគច្រើន',
    'bulk_update_help'	=> 'ទម្រង់បែបបទនេះអនុញ្ញាតឱ្យអ្នកធ្វើបច្ចុប្បន្នភាពទ្រព្យសម្បត្តិច្រើនក្នុងពេលតែមួយ។ បំពេញតែក្នុងវាលដែលអ្នកត្រូវការផ្លាស់ប្តូរ។ វាល​ណា​មួយ​ដែល​ទុក​នៅ​ទទេ​នឹង​នៅ​តែ​មិន​ផ្លាស់​ប្តូរ។ ',
    'bulk_update_warn'	=> 'អ្នក​រៀប​នឹង​កែ​សម្រួល​លក្ខណៈ​សម្បត្តិ​នៃ​ទ្រព្យ​សកម្ម​តែ​មួយ។|អ្នក​រៀប​នឹង​កែ​សម្រួល​លក្ខណៈ​សម្បត្តិ​របស់ :asset_count assets។',
    'bulk_update_with_custom_field' => 'ចំណាំទ្រព្យសកម្មគឺ :asset_model_count ប្រភេទផ្សេងគ្នានៃគំរូ។',
    'bulk_update_model_prefix' => 'នៅលើម៉ូដែល', 
    'bulk_update_custom_field_unique' => 'នេះ​គឺ​ជា​វាល​ពិសេស​មួយ ហើយ​មិន​អាច​ត្រូវ​បាន​កែ​សម្រួល​ច្រើន​ទេ។',
    'checkedout_to'		=> 'ប្រគល់ទៅអោយ',
    'checkout_date'		=> 'ថ្ងៃប្រគល់អោយ',
    'checkin_date'		=> 'កាលបរិច្ឆេទត្រឡប់មកវិញ',
    'checkout_to'		=> 'Checkout to',
    'cost'				=> 'ការចំណាយលើការទិញ',
    'create'			=> 'បង្កើតទ្រព្យសកម្ម',
    'date'				=> 'កាលបរិច្ឆេទទិញ',
    'depreciation'	    => 'ការរំលោះ',
    'depreciates_on'	=> 'ទម្លាក់តម្លៃលើ',
    'default_location'	=> 'ទីតាំងលំនាំដើម',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'កាលបរិច្ឆេទនៃ EOL',
    'eol_rate'			=> 'អត្រា EOL',
    'expected_checkin'  => 'កាលបរិច្ឆេទដែលរំពឹងទុកនឹង Checkin',
    'expires'			=> 'ផុតកំណត់',
    'fully_depreciated'	=> 'រំលោះទាំងស្រុង',
    'help_checkout'		=> 'ប្រសិនបើអ្នកចង់ផ្តល់ asset នេះភ្លាមៗ សូមជ្រើសរើស "Ready to Deploy" ពីបញ្ជីស្ថានភាពខាងលើ។ ',
    'mac_address'		=> 'MAC Address',
    'manufacturer'		=> 'ក្រុមហ៊ុនផលិត',
    'model'				=> 'គំរូ',
    'months'			=> 'ខែ',
    'name'				=> 'ឈ្មោះទ្រព្យសម្បត្តិ',
    'notes'				=> 'កំណត់ចំណាំ',
    'order'				=> 'លេខបញ្ជាទិញ',
    'qr'				=> 'QR Code',
    'requestable'		=> 'អ្នកប្រើប្រាស់អាចស្នើសុំ Asset នេះ',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'ជ្រើសរើសប្រភេទស្ថានភាព',
    'serial'			=> 'Serial',
    'status'			=> 'ស្ថានភាព',
    'tag'				=> 'ទ្រព្យសម្បត្តិ',
    'update'			=> 'ធ្វើបច្ចុប្បន្នភាព Asset',
    'warranty'			=> 'ការធានា',
        'warranty_expires'		=> 'ការធានាផុតកំណត់',
    'years'				=> 'ឆ្នាំ',
    'asset_location' => 'ធ្វើបច្ចុប្បន្នភាពទីតាំង Asset',
    'asset_location_update_default_current' => 'ធ្វើបច្ចុប្បន្នភាពទីតាំងលំនាំដើម និងទីតាំងជាក់ស្តែង',
    'asset_location_update_default' => 'ធ្វើបច្ចុប្បន្នភាពតែទីតាំងលំនាំដើមប៉ុណ្ណោះ។',
    'asset_location_update_actual' => 'ធ្វើបច្ចុប្បន្នភាពតែទីតាំងជាក់ស្តែងប៉ុណ្ណោះ។',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'កំពុងដំណើរការ... (វាអាចចំណាយពេលបន្តិចលើឯកសារធំ)',
    'optional_infos'  => 'ព័ត៌មានមិនសូវចាំបាច់',
    'order_details'   => 'ព័ត៌មានពាក់ព័ន្ធនឹងការបញ្ជាទិញ'
];
